#ifndef KYEXECTL_H
#define KYEXECTL_H

#include <stddef.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 获取文件的执行控制扩展属性并转换为可读的字符串
 *
 * @param path 文件路径
 * @param label 存储获取到的标记字符串
 * @return 成功 返回字符串长度，其他 失败
 */
extern int exectl_xattr_get(const char *path, char **label);

/**
 * @brief 设置文件的执行控制扩展属性
 *
 * @param path 文件路径
 * @return 0 成功，其他 失败
 */
extern int exectl_xattr_set(const char *path);

/**
 * @brief 批量设置文件的执行控制扩展属性
 *
 * @param paths 文件路径数组
 * @param count 文件数量
 * @return >= 0 设置成功的数量，其他 失败
 */
extern int exectl_xattr_multi_set(char *paths[], size_t count);

/**
 * @brief 遍历目录，设置文件的执行控制扩展属性
 *
 * @param dir 目录路径
 * @return 0 成功，其他 失败
 */
extern int exectl_xattr_set_for_dir(const char *dir);

/**
 * @brief 将文件的执行控制扩展清零
 *
 * @param path 文件路径
 * @return 0 成功，其他 失败
 */
extern int exectl_xattr_clear(const char *path);

/**
 * @brief 批量清除文件的执行控制扩展属性
 *
 * @param paths 文件路径数组
 * @param count 文件数量
 * @return >= 0 清除成功的数量，其他 失败
 */
extern int exectl_xattr_multi_clear(char *paths[], size_t count);

/**
 * @brief 遍历目录，将文件的执行控制扩展清零
 *
 * @param dir 目录路径
 * @return 0 成功，其他 失败
 */
extern int exectl_xattr_clear_for_dir(const char *dir);

/**
 * @brief 在初始化时设置标记
 *
 * @param path 文件路径
 * @return 0 成功，其他 失败
 */
extern int exectl_xattr_set_for_init(const char *rootmnt, const char *path);

/**
 * @brief 保存扫描结果
 *
 * @param rootmnt initrd的root
 * @param paths 扫描结果数组
 * @param size 文件数量
 * @return 0 成功，其他 失败
 */
extern int exectl_save_scanlist(const char *rootmnt, char *paths[], size_t size);

#ifdef __cplusplus
}
#endif

#endif /* KYEXECTL_H */

